import coinor.pulp as pulp
from pulp import *
import coinor.dippy as dippy

from math import floor, ceil

from facility_ex1 import REQUIREMENT, PRODUCTS, LOCATIONS, CAPACITY
##from facility_test1 import REQUIREMENT, PRODUCTS, LOCATIONS, CAPACITY
##from facility_test2 import REQUIREMENT, PRODUCTS, LOCATIONS, CAPACITY
##from facility_test6 import REQUIREMENT, PRODUCTS, LOCATIONS, CAPACITY

prob = LpProblem("Facility_Location")

assign_vars = LpVariable.dicts("AtLocation",
              [(i, j) for i in LOCATIONS
                      for j in PRODUCTS],
              0, 1, LpBinary)
use_vars    = LpVariable.dicts("UseLocation",
              LOCATIONS, 0, 1, LpBinary)
waste_vars  = LpVariable.dicts("Waste",
              LOCATIONS, 0, CAPACITY)

# objective: minimise waste
prob += sum(waste_vars[i] for i in LOCATIONS), "min"

# assignment constraints
for j in PRODUCTS:
    prob += sum(assign_vars[(i, j)] for i in LOCATIONS) == 1

# aggregate CAPACITY constraints
for i in LOCATIONS:
    prob += sum(assign_vars[(i, j)] * REQUIREMENT[j]
                for j in PRODUCTS) + waste_vars[i] == \
            CAPACITY * use_vars[i]

prob.solve()

# print solution
TOL = 0.00001
for i in LOCATIONS:
    if use_vars[i].varValue > TOL:
        print "Location ", i, " produces ", \
              [j for j in PRODUCTS
               if assign_vars[(i, j)].varValue > TOL]
